
## CATO-CLI - mutation.site.removeSecondaryAzureVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.removeSecondaryAzureVSocket) for documentation on this operation.

### Usage for mutation.site.removeSecondaryAzureVSocket:

`catocli mutation site removeSecondaryAzureVSocket -h`

`catocli mutation site removeSecondaryAzureVSocket <json>`

`catocli mutation site removeSecondaryAzureVSocket "$(cat < mutation.site.removeSecondaryAzureVSocket.json)"`

`catocli mutation site removeSecondaryAzureVSocket '{"socketId":"id"}'`

`catocli mutation site removeSecondaryAzureVSocket -p '{
    "socketId": "id"
}'`


#### Operation Arguments for mutation.site.removeSecondaryAzureVSocket ####

`accountId` [ID] - (required) N/A    
`socketId` [ID] - (required) N/A    
